#!/usr/bin/env python
# -*- coding: utf-8 -*-
# ----------------------------------------------------------------------------
# "THE BEER-WARE LICENSE" (Revision 42):
# <terry.yinzhe@gmail.com> wrote this file. As long as you retain this notice you
# can do whatever you want with this stuff. If we meet some day, and you think
# this stuff is worth it, you can buy me a beer in return to Terry Yin.
#
# The idea of this is borrowed from <mort.yao@gmail.com>'s brilliant work
#    https://github.com/soimort/google-translate-cli
# He uses "THE BEER-WARE LICENSE". That's why I use it too. So you can buy him a 
# beer too.
# ----------------------------------------------------------------------------
from unittest import TestCase
from subprocess import Popen, PIPE, check_output
from translate import Translator
import sys

decode = [lambda x:x, lambda x:x.decode("utf-8")][sys.version_info.major>2] 

class TestTranslate(TestCase):

    def test_tranlate_english_to_englsih(self):
        translator = Translator(to_lang="en")
        translation = translator.translate("why")
        self.assertEqual(u"why", translation)
		
    def test_translate_english_to_Chinese(self):
        translator = Translator(to_lang="zh")
        translation = translator.translate("why")
        self.assertEqual(u"为什么这样说呢？",translation)
		
    def test_translate_english_to_Chinese_Simple_sentence(self):
        translator = Translator(to_lang="zh")
        translation = translator.translate("why stop?")
        self.assertEqual(u"为什么停下来？",translation)

    def test_translate_With_Quote(self):
        translator = Translator(to_lang="zh")
        translation = translator.translate("What is \"yinyang\"?")
        self.assertEqual(u"\"阴阳\"是什么？",translation)

    def test_translate_With_multiple_sentences(self):
        translator = Translator(to_lang="zh")
        translation = translator.translate("yes. no.")
        self.assertIn(u'会 不会', translation)

class CommandLineTest(TestCase):
    def test_command_line_take_zh_as_default_language(self):
        result = check_output("translate why".split())
        self.assertIn(u'为什么', result.decode("utf-8"))
        
    def test_command_line_take_string_arg(self):
        result = check_output(["translate", 'This is a pen.'])
        self.assertIn(u'这是一支钢笔。', result.decode("utf-8").splitlines())
        
    def test_command_line_take_multiple_args(self):
        result = check_output(["translate", 'one', 'two'])
        self.assertIn(u'一个', result.decode("utf-8").splitlines())
        self.assertIn(u'二个', result.decode("utf-8").splitlines())
        
    def test_command_line_to_language(self):
        result = check_output(["translate", '--to', 'zh-TW', 'love'])
        self.assertIn(u'愛', result.decode("utf-8").splitlines())

    def test_command_line_from_language(self):
        result = check_output(["translate", '--from', 'ja', '美'])
        self.assertIn(u'美', result.decode("utf-8").splitlines())



#!/usr/bin/env python
# encoding: utf-8
'''
'''
import translate
from distutils.core import setup
def install():
    try:
        long_description = open("README.rst").read()
    except:
        long_description = translate.__doc__
    setup(
          name = 'translate',
          version = "2.0.0",
          description = translate.__doc__,
          long_description = long_description,
          url = 'https://github.com/terryyin/google-translate-python',
          classifiers = ['Development Status :: 5 - Production/Stable',
                     'Intended Audience :: Education',
                     'Intended Audience :: End Users/Desktop',
                     'License :: Freeware',
                     'Operating System :: POSIX',
                     'Operating System :: Microsoft :: Windows',
                     'Operating System :: MacOS :: MacOS X',
                     'Topic :: Education',
                     'Programming Language :: Python',
                     'Programming Language :: Python :: 2.6',
                     'Programming Language :: Python :: 2.7',
                     'Programming Language :: Python :: 3.2',
                     'Programming Language :: Python :: 3.3',
                     'Programming Language :: Python :: 3.4'],
          py_modules = ['translate'],
          author = 'Terry Yin',
          author_email = 'terry.yinze@gmail.com',
          scripts=['translate']
          )

if __name__ == "__main__":
    install()



#!/usr/bin/env python
# ----------------------------------------------------------------------------
# "THE BEER-WARE LICENSE" (Revision 42):
# <terry.yinzhe@gmail.com> wrote this file. As long as you retain this notice you
# can do whatever you want with this stuff. If we meet some day, and you think
# this stuff is worth it, you can buy me a beer in return to Terry Yin.
#
# Now google has stop providing free translation API. So I have to switch to
# http://mymemory.translated.net/, which has a limit for 1000 words/day free
# usage.
#
# The original idea of this is borrowed from <mort.yao@gmail.com>'s brilliant work
#    https://github.com/soimort/google-translate-cli
# ----------------------------------------------------------------------------
'''
This is a simple, yet powerful command line translator with google translate
behind it. You can also use it as a Python module in your code.
'''
import re
import json
from textwrap import wrap
try:
    import urllib2 as request
    from urllib import quote
except:
    from urllib import request
    from urllib.parse import quote

class Translator:
    def __init__(self, to_lang, from_lang='en'):
        self.from_lang = from_lang
        self.to_lang = to_lang

    def translate(self, source):
        if self.from_lang == self.to_lang:
            return source
        self.source_list = wrap(source, 1000, replace_whitespace=False)
        return ' '.join(self._get_translation_from_google(s) for s in self.source_list)

    def _get_translation_from_google(self, source):
        json5 = self._get_json5_from_google(source)
        return json.loads(json5)['responseData']['translatedText']

    def _get_json5_from_google(self, source):
        escaped_source = quote(source, '')
        headers = {'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.168 Safari/535.19'}
        req = request.Request(
             url="http://mymemory.translated.net/api/get?q=%s&langpair=%s|%s" % (escaped_source, self.from_lang, self.to_lang)
                 , headers = headers)

             #url="http://translate.google.com/translate_a/t?clien#t=p&ie=UTF-8&oe=UTF-8"
                 #+"&sl=%s&tl=%s&text=%s" % (self.from_lang, self.to_lang, escaped_source)
                 #, headers = headers)
        r = request.urlopen(req)
        return r.read().decode('utf-8')

def main(defvals=None):
    import argparse
    import sys
    import locale

    if defvals is None:
       defvals = {'f':'en', 't':'zh'} 

    parser = argparse.ArgumentParser(description=__doc__)
    parser.add_argument('texts', metavar='text', nargs='+',
                   help='a string to translate(use "" when it\'s a sentence)')
    parser.add_argument('-t', '--to', dest='to_lang', type=str, default=defvals['t'],
                   help='To language (e.g. zh, zh-TW, en, ja, ko). Default is '+defvals['t']+'.')
    parser.add_argument('-f', '--from', dest='from_lang', type=str, default=defvals['f'],
                   help='From language (e.g. zh, zh-TW, en, ja, ko). Default is '+defvals['f']+'.')
    args = parser.parse_args()
    translator= Translator(from_lang=args.from_lang, to_lang=args.to_lang)
    for text in args.texts:
        translation = translator.translate(text)
        if sys.version_info.major == 2:
            translation =translation.encode(locale.getpreferredencoding())
        sys.stdout.write(translation)
        sys.stdout.write("\n")

if __name__ == "__main__":
    main()
